@@ -26,6 +26,12 @@ class OsDebugWriter(object):
         if self.file:
             self.file.flush(*args, **kwargs)
             
+    def clearMemory(self):
+        pass
+    
+    def getMemory(self):
+        return []
+            
 class OsDebugMemory(OsDebugWriter):
     def __init__(self):
         super(OsDebugMemory, self).__init__(False)
@@ -38,6 +44,12 @@ class OsDebugMemory(OsDebugWriter):
         #print 'FLUSH:', args
         pass
     
+    def clearMemory(self):
+        self.memory = []
+        
+    def getMemory(self):
+        return self.memory
+    
 
 class OsDebug(object):
     LEVELS = {
