@@ -204,7 +204,7 @@ class SambaWalker(OsWalker):
             '\>':False,
             'ONLY_ME':True
         }
-        super(SSambaWalker,self).__init__(False, baseWalker)
+        super(SambaWalker,self).__init__(False, baseWalker)
 
     def connectCommand(self):
         return ' '.join([
